# FRET

The **FRET** submodule provides all the functionality to calculate distance and FRET distributions between a donor and an acceptor ACV cloud.

```{eval-rst}
.. automodule:: fretraj.fret
   :members:
   :undoc-members:
```
